Exec sp_configure 'Recovery Interval',3
Go
Reconfigure with Override
Go

-- create and then detach a database
create database test
go
Exec sp_detach_db 'test'

--now attach it
EXEC sp_attach_db @dbname = 'test',
@filename1 = 'd:\program files\microsoft sql server\mssql\data\test.mdf',
@filename2 = 'd:\program files\microsoft sql server\mssql\data\test_log.ldf'


-- restoring a full database from a backup
RESTORE DATABASE PUBS FROM PUBS_BACKUP

--*******************************************
-- let's set up the next couple of scenarios
--*******************************************
exec sp_dropdevice 'pubs_backup','DELFILE'
go
exec sp_addumpdevice 'disk','pubs_backup','d:\program files\microsoft sql server\mssql\backup\pubs_backup.bak'
--create backup file #1 (full database backup)
backup database pubs to pubs_backup with init
go
use pubs
create table table1 (c1 int not null)
insert table1 values (1)
-- create backup file #2 (full database backup)
backup database pubs to pubs_backup with noinit
create table table2 (c1 int not null)
insert table2 values (1)
-- create backup file #3 (full database backup)
backup database pubs to pubs_backup with noinit
insert table1 values (2)
insert table2 values (3)
-- create backup file #4 (tran log backup)
backup log pubs to pubs_backup with noinit
--*****************************
-- DONE WITH SCENARIO SETUP ***
--*****************************

-- restore from the 3rd set of files on the backup

--Step 1 (verify what #3 is):
RESTORE HEADERONLY from pubs_backup
--Step 2 (restore from file #3):
use master
RESTORE DATABASE PUBS FROM PUBS_BACKUP WITH FILE = 3

-- A complicated restore:
RESTORE DATABASE PUBS FROM PUBS_BACKUP
WITH MOVE 'pubs' TO 'D:\pubs.mdf',
FILE = 3,
STANDBY = 'd:\standby.dat',
STATS = 25

-- now restore to the log you took
restore log pubs from pubs_backup with file = 4, RECOVERY

-- A log restore sample code:
--RESTORE LOG pubs from pubs_log_backup

-- "traditional" full database recovery
RESTORE DATABASE pubs FROM pubs_backup WITH NORECOVERY
RESTORE LOG pubs from pubs_log_backup WITH RECOVERY

--*****************************
-- Set up the next scenario ***
--*****************************
use pubs
drop table table1
drop table table2
go
exec sp_dropdevice 'pubs_backup','DELFILE'
exec sp_dropdevice 'pubs_log_backup','DELFILE'
go
exec sp_addumpdevice 'disk','pubs_backup','d:\program files\microsoft sql server\mssql\backup\pubs_backup.bak'
exec sp_addumpdevice 'disk','pubs_log_backup','d:\program files\microsoft sql server\mssql\backup\pubs_log_backup.bak'
--create backup file #1 (full database backup)
backup database pubs to pubs_backup with init
go
use pubs
create table table1 (c1 int not null)
insert table1 values (1)
-- create backup file #1 (tran log backup)
backup log pubs to pubs_log_backup with noinit
create table table2 (c1 int not null)
insert table2 values (1)
-- create backup file #2 (tran log backup)
backup log pubs to pubs_log_backup with noinit
insert table1 values (2)
insert table2 values (3)
-- create backup file #3 (tran log backup)
backup log pubs to pubs_log_backup with noinit
--*****************************
-- DONE WITH SCENARIO SETUP ***
--*****************************

-- restore and then apply 3 log entries.
use master
RESTORE DATABASE pubs FROM pubs_backup WITH NORECOVERY
RESTORE LOG pubs from pubs_log_backup WITH FILE = 1, NORECOVERY
RESTORE LOG pubs from pubs_log_backup WITH FILE = 2, NORECOVERY
RESTORE LOG pubs from pubs_log_backup WITH FILE = 3, RECOVERY

-- examine the backups
restore headeronly from pubs_log_backup

-- now restore to a point in time (change date/time to match something valid in your backup)
use master
RESTORE DATABASE pubs FROM pubs_backup WITH NORECOVERY
RESTORE LOG pubs from pubs_log_backup WITH FILE = 1, NORECOVERY
RESTORE LOG pubs from pubs_log_backup WITH FILE = 2, NORECOVERY
RESTORE LOG pubs from pubs_log_backup WITH FILE = 3, RECOVERY,
STOPAT = 'Jul 29, 2000 5:17 PM'


-- OK, now let's recover to a marked point in the transaction log
use pubs
drop table table3
drop table table4

exec sp_dropdevice 'pubs_backup','DELFILE'
exec sp_dropdevice 'pubs_log_backup','DELFILE'
go
exec sp_addumpdevice 'disk','pubs_backup','d:\program files\microsoft sql server\mssql\backup\pubs_backup.bak'
exec sp_addumpdevice 'disk','pubs_log_backup','d:\program files\microsoft sql server\mssql\backup\pubs_log_backup.bak'
--create backup file #1 (full database backup)
backup database pubs to pubs_backup with init
go
use pubs
create table table3 (c1 int not null)
BEGIN TRANSACTION tran1 WITH MARK 'My first mark'
insert table3 values (1)
COMMIT TRANSACTION tran1
-- create backup file #1 (tran log backup)
backup log pubs to pubs_log_backup with noinit
create table table4 (c1 int not null)
insert table4 values (1)
-- create backup file #2 (tran log backup)
backup log pubs to pubs_log_backup with noinit
insert table3 values (2)
BEGIN TRANSACTION tran2 WITH MARK 'my second mark'
insert table3 values (3)
insert table4 values (3)
COMMIT TRANSACTION tran2
-- create backup file #3 (tran log backup)
backup log pubs to pubs_log_backup with noinit

--OK, let's do the actual restores now
use master
RESTORE DATABASE pubs FROM pubs_backup WITH NORECOVERY
RESTORE LOG pubs from pubs_log_backup WITH FILE = 1, NORECOVERY
RESTORE LOG pubs from pubs_log_backup WITH FILE = 2, NORECOVERY
RESTORE LOG pubs from pubs_log_backup WITH FILE = 3, 
STOPATMARK = 'tran2'

-- Combining differential and transaction log backups
use pubs
drop table table3
drop table table4

exec sp_dropdevice 'pubs_backup','DELFILE'
exec sp_dropdevice 'pubs_log_backup','DELFILE'
go
exec sp_addumpdevice 'disk','pubs_backup','d:\program files\microsoft sql server\mssql\backup\pubs_backup.bak'
exec sp_addumpdevice 'disk','pubs_log_backup','d:\program files\microsoft sql server\mssql\backup\pubs_log_backup.bak'
--create backup file #1 (full database backup)
backup database pubs to pubs_backup with init
go
use pubs
create table table3 (c1 int not null)
insert table3 values (1)
create table table4 (c1 int not null)
insert table4 values (1)
-- create a differential backup
backup database pubs to pubs_backup with differential, noinit
insert table3 values (2)
insert table3 values (3)
insert table4 values (3)
-- create backup file #3 (tran log backup)
backup log pubs to pubs_log_backup with init

-- Restore the database, then the differential, then the log
use master
RESTORE DATABASE pubs FROM pubs_backup WITH FILE = 1, NORECOVERY
RESTORE DATABASE pubs FROM pubs_backup WITH FILE = 2, NORECOVERY
RESTORE LOG pubs from pubs_log_backup WITH FILE = 1, RECOVERY


-- Sample code to restore from a filegroup backup
-- for this to work you must create a database named test, create a file named test_data.
RESTORE DATABASE test FILE = 'test_data'
FROM test_file_backup WITH NORECOVERY
RESTORE LOG test FROM test_log_backup WITH RECOVERY

-- try to restore master
-- first, make a backup
backup database master to master_backup with init
go
-- now, attempt the restore
restore database master from master_backup with recovery
